@@ -218,7 +218,9 @@ class MycobotCommandGenerater(DataProcessor):
             speed(int): 0 ~ 100
         """
         check_datas(speed=speed)
-        return self._mesg(Command.SEND_COORD, id, [self._coord_to_int(coord)], speed)
+        return self._mesg(
+            Command.SEND_COORD, id - 1, [self._coord_to_int(coord)], speed
+        )
 
     def send_coords(self, coords, speed, mode):
         """Send all coordinations.
@@ -319,9 +321,26 @@ class MycobotCommandGenerater(DataProcessor):
         return self._mesg(Command.SET_ENCODER, joint_id, [encoder])
 
     def get_encoder(self, joint_id):
+        """Get servo encoder
+
+        Args:
+            joint_id (int): servo number.
+
+        Returns:
+            (int16): servo encoder value.
+        """
         return self._mesg(Command.GET_ENCODER, joint_id, has_reply=True)
 
     def set_encoders(self, encoders, sp):
+        """Set all servo encoder.
+
+        Args:
+            encoders (list): encoder list
+            sp (int): speed
+
+        Returns:
+            (str): command.
+        """
         return self._mesg(Command.SET_ENCODERS, encoders, sp)
 
     def get_encoders(self):
@@ -362,7 +381,7 @@ class MycobotCommandGenerater(DataProcessor):
 
     # Servo control
     def is_servo_enable(self, servo_id):
-        return self._mesg(Command.IS_SERVO_ENABLE, servo_id)
+        return self._mesg(Command.IS_SERVO_ENABLE, servo_id, has_reply=True)
 
     def is_all_servo_enable(self):
         return self._mesg(Command.IS_ALL_SERVO_ENABLE, has_reply=True)
